@@ -98,9 +98,9 @@ test_that("ard_stack() adding overalls", {
     bind_ard(
       ard_continuous(data = mtcars, by = "cyl", variables = "mpg"),
       ard_dichotomous(data = mtcars, by = "cyl", variables = "vs"),
-      ard_categorical(data = mtcars, variables = "cyl"),
       ard_continuous(data = mtcars, variables = "mpg"),
       ard_dichotomous(data = mtcars, variables = "vs"),
+      ard_categorical(data = mtcars, variables = "cyl"),
       .update = TRUE,
       .order = TRUE
     )
@@ -127,9 +127,9 @@ test_that("ard_stack() adding missing/attributes", {
     bind_ard(
       ard_continuous(data = mtcars, by = "cyl", variables = "mpg"),
       ard_dichotomous(data = mtcars, by = "cyl", variables = "vs"),
-      ard_categorical(data = mtcars, variables = "cyl"),
       ard_missing(data = mtcars, by = "cyl", variables = c("mpg", "vs")),
-      ard_attributes(mtcars, variables = c("cyl", "mpg", "vs")),
+      ard_categorical(data = mtcars, variables = "cyl"),
+      ard_attributes(mtcars, variables = c("mpg", "vs", "cyl")),
       .update = TRUE,
       .order = TRUE
     )
@@ -157,9 +157,9 @@ test_that("ard_stack() adding missing/attributes", {
       ard_missing(data = mtcars, by = "cyl", variables = c("mpg", "vs")),
       ard_continuous(data = mtcars, variables = "mpg"),
       ard_dichotomous(data = mtcars, variables = "vs"),
-      ard_missing(data = mtcars, variables = c("mpg", "vs")),
       ard_categorical(data = mtcars, variables = "cyl"),
-      ard_attributes(mtcars, variables = c("cyl", "mpg", "vs")),
+      ard_missing(data = mtcars, variables = c("mpg", "vs")),
+      ard_attributes(mtcars, variables = c("mpg", "vs", "cyl")),
       .update = TRUE,
       .order = TRUE
     )
